#!/home/ktietz/ci_310/portpicker_1646228732730/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/bin/python
# EASY-INSTALL-SCRIPT: 'portpicker==1.3.1','portserver.py'
__requires__ = 'portpicker==1.3.1'
__import__('pkg_resources').run_script('portpicker==1.3.1', 'portserver.py')
